==> owncloud-app-contacts-2%3A1.2.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/pt_BR.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contatos",
    "Address book name" : "Nome do livro de endereços",
    "No contacts in here" : "Nenhum contato aqui",
    "Name" : "Nome",
    "Organization" : "Organização",
    "Title" : "Título",
    "Add field ..." : "Adicionar campo...",
    "Import" : "Importar",
    "Add contact" : "Adicionar contatos",
    "No search result for {query}" : "Nenhum resultado de busca para {query}",
    "All contacts" : "Todos os contatos",
    "Not grouped" : "Não agrupado",
    "Post Office Box" : "Caixa de Correio",
    "Postal Code" : "Código Postal",
    "City" : "Cidade",
    "State or province" : "Estado ou província",
    "Country" : "País",
    "Address" : "Endereço",
    "(new group)" : "(novo grupo)",
    "New contact" : "Novo contato",
    "{addressbook} shared by {owner}" : "{addressbook} compartilhado por {owner}",
    "Invalid file type." : "Tipo de arquivo inválido.",
    "Nickname" : "Apelido",
    "Notes" : "Notas",
    "Website" : "Website",
    "Federated Cloud ID" : "ID de núvem Associada",
    "Home" : "Casa",
    "Work" : "Trabalho",
    "Other" : "Outro",
    "Groups" : "Grupos",
    "Birthday" : "Aniversário",
    "Email" : "E-mail",
    "Instant messaging" : "Mensagem instantânea",
    "Phone" : "Telefone",
    "Mobile" : "Móvel",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do trabalho",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Social Network" : "Rêde Social",
    "Settings" : "Configurações"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-app-contacts-2%3A1.3.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/pt_BR.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contatos",
    "Address book name" : "Nome do livro de endereços",
    "No contacts in here" : "Nenhum contato aqui",
    "Name" : "Nome",
    "Organization" : "Organização",
    "Title" : "Título",
    "Add field ..." : "Adicionar campo...",
    "Import" : "Importar",
    "Add contact" : "Adicionar contatos",
    "No search result for {query}" : "Nenhum resultado de busca para {query}",
    "All contacts" : "Todos os contatos",
    "Not grouped" : "Não agrupado",
    "Post Office Box" : "Caixa de Correio",
    "Postal Code" : "Código Postal",
    "City" : "Cidade",
    "State or province" : "Estado ou província",
    "Country" : "País",
    "Address" : "Endereço",
    "(new group)" : "(novo grupo)",
    "New contact" : "Novo contato",
    "{addressbook} shared by {owner}" : "{addressbook} compartilhado por {owner}",
    "No contacts in file. Only VCard files are allowed." : "Nenhum contato em arquivo. Somente arquivos vCard são permitidos.",
    "Nickname" : "Apelido",
    "Notes" : "Notas",
    "Website" : "Website",
    "Federated Cloud ID" : "ID de núvem Associada",
    "Home" : "Casa",
    "Work" : "Trabalho",
    "Other" : "Outro",
    "Groups" : "Grupos",
    "Birthday" : "Aniversário",
    "Email" : "E-mail",
    "Instant messaging" : "Mensagem instantânea",
    "Phone" : "Telefone",
    "Mobile" : "Móvel",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do trabalho",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Social Network" : "Rêde Social",
    "Settings" : "Configurações"
},
"nplurals=2; plural=(n > 1);");
